# autogenerated by ssc-gen DO NOT_EDIT
from __future__ import annotations
import re
from typing import List, TypedDict, Union
from parsel import Selector, SelectorList

T_OngoingPage = TypedDict("T_OngoingPage", {"url": str, "title": str, "thumbnail": str})
T_SearchPage = TypedDict("T_SearchPage", {"title": str, "thumbnail": str, "url": str})
T_AnimePage = TypedDict(
    "T_AnimePage", {"title": str, "alt_title": str, "description": str, "thumbnail": str, "player_url": str}
)
T_PlaylistURLPage = TypedDict("T_PlaylistURLPage", {"playlist_url": str})


class OngoingPage:
    """GET https://sameband.studio/novinki

    [
        {
            "url": "String",
            "title": "String",
            "thumbnail": "String"
        },
        "..."
    ]"""

    def __init__(self, document: Union[str, SelectorList, Selector]):
        self._doc = Selector(document) if isinstance(document, str) else document

    def _split_doc(self, value: Selector) -> SelectorList:
        value1 = value.css(".col-auto")
        return value1

    def _parse_url(self, value: Selector) -> str:
        value1 = value.css("a")
        value2 = value1.css("::attr(href)").get()
        return value2

    def _parse_title(self, value: Selector) -> str:
        value1 = value.css(".col-auto .poster")
        value2 = value1.css("::attr(title)").get()
        return value2

    def _parse_thumbnail(self, value: Selector) -> str:
        value1 = value.css("img.swiper-lazy")
        value2 = value1.css("::attr(src)").get()
        value3 = "https://sameband.studio{}".format(value2) if value2 else value2
        return value3

    def parse(self) -> List[T_OngoingPage]:
        return [
            {"url": self._parse_url(e), "title": self._parse_title(e), "thumbnail": self._parse_thumbnail(e)}
            for e in self._split_doc(self._doc)
        ]


class SearchPage:
    """
        POST https://sameband.studio/index.php?do=search
        do=search&subaction=search&search_start=0&full_search=0&result_from=1&story=<QUERY>

        NOTE:
            search query len should be 4 or more characters. And in manual tests, works only cyrillic queries

        EXAMPLE:
            POST https://sameband.studio/index.php?do=search
        do=search&subaction=search&search_start=0&full_search=0&result_from=1&story=ВЕДЬ


    [
        {
            "title": "String",
            "thumbnail": "String",
            "url": "String"
        },
        "..."
    ]"""

    def __init__(self, document: Union[str, SelectorList, Selector]):
        self._doc = Selector(document) if isinstance(document, str) else document

    def _split_doc(self, value: Selector) -> SelectorList:
        value1 = value.css(".col-auto")
        return value1

    def _parse_title(self, value: Selector) -> str:
        value1 = value.css(".col-auto .poster")
        value2 = value1.css("::attr(title)").get()
        return value2

    def _parse_thumbnail(self, value: Selector) -> str:
        value1 = value.css("img.swiper-lazy")
        value2 = value1.css("::attr(src)").get()
        value3 = "https://sameband.studio{}".format(value2) if value2 else value2
        return value3

    def _parse_url(self, value: Selector) -> str:
        value1 = value.css(".image")
        value2 = value1.css("::attr(href)").get()
        return value2

    def parse(self) -> List[T_SearchPage]:
        return [
            {"title": self._parse_title(e), "thumbnail": self._parse_thumbnail(e), "url": self._parse_url(e)}
            for e in self._split_doc(self._doc)
        ]


class AnimePage:
    """
        GET https://sameband.studio/anime/<ANIME PATH>.html

        EXAMPLE:
            # https://sameband.studio/anime/20-госпожа-кагуя-3.html
            GET https://sameband.studio/anime/20-%D0%B3%D0%BE%D1%81%D0%BF%D0%BE%D0%B6%D0%B0-%D0%BA%D0%B0%D0%B3%D1%83%D1%8F-3.html


    {
        "title": "String",
        "alt_title": "String",
        "description": "String",
        "thumbnail": "String",
        "player_url": "String"
    }"""

    def __init__(self, document: Union[str, SelectorList, Selector]):
        self._doc = Selector(document) if isinstance(document, str) else document

    def _parse_title(self, value: Selector) -> str:
        value1 = value.css("h1.m-0")
        value2 = value1.css("::text").get()
        return value2

    def _parse_alt_title(self, value: Selector) -> str:
        value1 = value.css(".help")
        value2 = value1.css("::text").get()
        return value2

    def _parse_description(self, value: Selector) -> str:
        value1 = value.css(".limiter span")
        value2 = value1.css("::text").getall()
        value3 = " ".join(value2)
        return value3

    def _parse_thumbnail(self, value: Selector) -> str:
        value1 = value.css(".image > img")
        value2 = value1.css("::attr(src)").get()
        value3 = "https://sameband.studio{}".format(value2) if value2 else value2
        return value3

    def _parse_player_url(self, value: Selector) -> str:
        value1 = value.css(".player > .player-content > iframe")
        value2 = value1.css("::attr(src)").get()
        value3 = "https://sameband.studio{}".format(value2) if value2 else value2
        return value3

    def parse(self) -> T_AnimePage:
        return {
            "title": self._parse_title(self._doc),
            "alt_title": self._parse_alt_title(self._doc),
            "description": self._parse_description(self._doc),
            "thumbnail": self._parse_thumbnail(self._doc),
            "player_url": self._parse_player_url(self._doc),
        }


class PlaylistURLPage:
    """GET https://sameband.studio/pl/a/<PLAYLIST NAME>.html

        EXAMPLE:
            GET https://sameband.studio/pl/a/Mashle_2nd_Season.html


    {
        "playlist_url": "String"
    }"""

    def __init__(self, document: Union[str, SelectorList, Selector]):
        self._doc = Selector(document) if isinstance(document, str) else document

    def _parse_playlist_url(self, value: Selector) -> str:
        value1 = value.get()
        value2 = re.search("var\\s*player\\s*=[^>]+file:[\\\"']([^>]+)[\\\"']", value1)[1]
        value3 = "https://sameband.studio{}".format(value2) if value2 else value2
        return value3

    def parse(self) -> T_PlaylistURLPage:
        return {"playlist_url": self._parse_playlist_url(self._doc)}
